import{j as e,B as r,G as s,a as o,c as t,b as a,r as d,T as i}from"./Base-rYbAJ89M.js";function n(){return e.jsx(r,{breadCrumbList:[],children:e.jsx(s,{size:{xs:12,md:9},py:2,pl:2,children:e.jsx(o,{p:2,sx:{border:"1px solid",borderColor:"grey.300",borderRadius:1,minHeight:300},children:"Empty Page"})})})}const c=t({palette:{primary:{main:"#00d5be"},secondary:{main:"#7c86ff"}},components:{MuiDrawer:{styleOverrides:{backdrop:{backgroundColor:"#fff"}}}}});a.createRoot(document.getElementById("root")).render(e.jsx(d.StrictMode,{children:e.jsx(i,{theme:c,children:e.jsx(n,{})})}));
//# sourceMappingURL=main-B0HmeKIv.js.map
