{% extends "platform/base.html" %}

{% block extra_head %}
    <link rel="modulepreload" crossorigin href="/static/assets/Base-rYbAJ89M.js">
    <link rel="stylesheet" href="/static/assets/Base-Dye7VA9w.css">
    <script type="module" crossorigin src="/static/assets/main-B0HmeKIv.js"></script>
{% endblock %}
