# Generated by Django 5.2.8 on 2025-11-18 06:11

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("django_email_learning", "0001_initial"),
    ]

    operations = [
        migrations.CreateModel(
            name="BlockedEmail",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("email", models.EmailField(max_length=254, unique=True)),
            ],
        ),
        migrations.AlterField(
            model_name="imapconnection",
            name="port",
            field=models.IntegerField(db_default=993),
        ),
    ]
